Contributing
============

Like every open-source project, Django-rgallery is always looking for
motivated individuals to contribute to it's source code.

Community
---------

People interested in developing for the Django-rgallery should head
over to #codigo23 on the `freenode`_ IRC network for help and to
discuss the development.

You may also be interested in following `@oscarmlage`_ on Twitter.

.. note::

  This very document is based on the contributing docs of the
  `django-compressor`_ project. Many thanks for allowing us to steal it!

.. _@oscarmlage : https://twitter.com/oscarmlage
.. _django-compressor : http://django-compressor.readthedocs.org/
